@@ -3,6 +3,7 @@
 #' @author Marc Girondot
 #' @return A list with a P_TRT object containing a matrix with lower and higher bounds for TRT, TRT and P and a P_TRT_quantiles object with quantiles for each and a sexratio_quantiles object
 #' @param x Set of parameters or a result of tsd()
+#' @param fixed.parameters Set of fixed parameters
 #' @param resultmcmc A result of tsd_MHmcmc()
 #' @param chain What chain to be used is resultmcmc is provided
 #' @param temperatures If provided returns the sex ratio and its quantiles for each temperature
@@ -17,9 +18,12 @@
 #' @description Estimate the parameters that best describe the thermal reaction norm for sex ratio when temperature-dependent sex determination occurs.\cr
 #' It can be used also to evaluate the relationship between incubation duration and sex ratio.\cr
 #' The parameter l was defined in Girondot (1999). The TRT is defined from the difference between the two boundary temperatures giving sex ratios of l and 1 - l.\cr
-#' For logistic equation, exact value is used and precision iterations are used for other equations.\cr
 #' In Girondot (1999), l was 0.05 and then the TRT was defined as being the range of temperatures producing from 5% to 95% of each sex.\cr
 #' If l is null, TRT is not estimated and only sex ratio is estimated.\cr
+#' if replicate.CI is null or 0, no replicate is used and only point estimate is done.\cr
+#' Standard error is calculated using resampling based on the Hessian matrix with Cholesky decomposition 
+#' or using MCMC chain if resultmcmc is provided. In the former case, a replicate.CI random sample of the 
+#' MCMC results will be used.\cr
 #' @references Girondot, M. 1999. Statistical description of temperature-dependent sex determination using maximum likelihood. Evolutionary Ecology Research, 1, 479-486.
 #' @references Godfrey, M.H., Delmas, V., Girondot, M., 2003. Assessment of patterns of temperature-dependent sex determination using maximum likelihood model selection. Ecoscience 10, 265-272.
 #' @references Hulin, V., Delmas, V., Girondot, M., Godfrey, M.H., Guillon, J.-M., 2009. Temperature-dependent sex determination and global change: are some species at greater risk? Oecologia 160, 493-506.
@@ -47,19 +51,22 @@
 #' }
 #' @export
 
-P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05, 
+P_TRT <- function(x=NULL, resultmcmc=NULL, fixed.parameters=NULL, 
+                  chain=1, equation=NULL, l=0.05, 
                   replicate.CI=NULL, temperatures=NULL, durations=NULL,
                   SD.temperatures= NULL, SD.durations=NULL,
                   probs=c(0.025, 0.5, 0.975), 
                   warn=TRUE) {
   
+  # x=NULL; resultmcmc=NULL; fixed.parameters=NULL; chain=1; equation=NULL; l=0.05; replicate.CI=NULL; temperatures=NULL; durations=NULL; SD.temperatures= NULL; SD.durations=NULL; probs=c(0.025, 0.5, 0.975); warn=TRUE
+  
   modelTSD <- getFromNamespace(".modelTSD", ns="embryogrowth")
   
   # resultmcmc=NULL; chain=1; equation=NULL; l=0.05; replicate.CI=NULL; temperatures=NULL; durations=NULL; SD.temperatures= NULL; SD.durations=NULL; probs=c(0.025, 0.5, 0.975); warn=TRUE
   if (is.null(x) & is.null(resultmcmc)) stop("Or x or resultmcmc must be provided")
   if (!is.null(temperatures) & !is.null(durations)) stop("Temperatures and durations cannot be provided at the same time")
   
-  if (class(x) == "tsd") {
+  if (any(class(x) == "tsd")) {
     type <- x$type
   } else {
     if (!is.null(temperatures)) {
@@ -71,6 +78,16 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
   
   if (!is.null(replicate.CI)) if (replicate.CI == 0) replicate.CI <- NULL
   
+  # Si j'ai un result mcmc mais pas de replicate.CI, je ne l'utilise pas
+  if (is.null(replicate.CI) & any(class(resultmcmc)=="mcmcComposite")) {
+    message("The mcmc result is not used because replicate.CI is null or 0")
+    resultmcmc <- NULL
+  }
+  
+  if (is.null(replicate.CI) & any(class(x)=="mcmcComposite")) {
+    stop("The mcmc result cannot be used because replicate.CI is null or 0")
+  }
+  
   temperatures <- c(temperatures, durations)
   SD <- c(SD.temperatures, SD.durations)
   
@@ -81,54 +98,101 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
   par <- NULL
   
   # TRT.limits <- c(1, 90)
-  precision <- 15
   
-  if (class(x)=="mcmcComposite" | class(resultmcmc)=="mcmcComposite") {
-    if (class(x)=="mcmcComposite") {
+  if (any(class(x)=="mcmcComposite") | any(class(resultmcmc)=="mcmcComposite")) {
+    if (any(class(x)=="mcmcComposite")) {
       par <- x$resultMCMC[[chain]]
       if (is.null(equation)) equation <- x$equation
+      fixed.parameters <- x$fixed.parameters
+      names.par <- colnames(x$resultMCMC[[chain]])
     }
-    if (class(resultmcmc)=="mcmcComposite") {
+    if (any(class(resultmcmc)=="mcmcComposite")) {
       par <- resultmcmc$resultMCMC[[chain]]
-      if (class(x)=="tsd") equation <- x$equation
+      names.par <- colnames(resultmcmc$resultMCMC[[chain]])
+      if (any(class(x)=="tsd")) {
+        equation <- x$equation
+        fixed.parameters <- x$fixed.parameters
+      }
       if (is.null(equation)) equation <- resultmcmc$equation
     }
+    if (replicate.CI > nrow(par)) {
+      warning("More replicates than mcmc iterations are demanded. It is not correct. Take care.")
+    }
+    if (replicate.CI == nrow(par))
+      sp <- 1:nrow(par)
+    else
+      sp <- sample(x=1:nrow(par), size=replicate.CI, replace = TRUE)
+    
+    par <- par[sp, , drop = FALSE]
+    
   } else {
-    if (class(x)=="tsd") {
+    if (any(class(x)=="tsd")) {
       equation <- x$equation
+      names.par <- names(x$par)
+      fixed.parameters <- x$fixed.parameters
       if (!is.null(replicate.CI) & (!is.null(x$hessian))) {
-        if (requireNamespace("lmf")) {
+        if (suppressPackageStartupMessages(requireNamespace("lmf"))) {
           partot <- matrix(x$par, nrow=1)
-          colnames(partot) <- names(x$par)
-          partot <- partot[-1, ]
+          colnames(partot) <- names.par
+          partot <- partot[-1, , drop=FALSE]
           
           errorsignS <- 0
+          errorsignS_low <- 0
+          errorsignS_high <- 0
           errorsignK1 <- 0
+          errorsignK1_low <- 0
+          errorsignK1_high <- 0
           errorsignK2 <- 0
+          errorsignK2_low <- 0
+          errorsignK2_high <- 0
           errorsignK <- 0
           errorsigncpt <- 0
           
           vcov <- solve(x$hessian)
           
           repeat {
-            
+            lm <- nrow(partot)
+            if (is.null(lm)) lm <- 0
             # 2019-05-31 : if replicate.CI == 1, renvoie quand même un nombre random
-            par <- getFromNamespace("rmnorm", ns="lmf")(n = replicate.CI-nrow(partot), mean = x$par, vcov)
+            par <- getFromNamespace("rmnorm", ns="lmf")(n = replicate.CI-lm, mean = x$par, vcov)
             # par <- getFromNamespace("rmnorm", ns="lmf")(n = replicate.CI-1, mean = x$par, vcov)
             # par <- rbind(x$par, par)
             if (!is.matrix(par)) {
               par <- matrix(par, nrow = 1)
-              colnames(par) <- names(x$par)
             }
+            colnames(par) <- names.par
+            
+            # 19/10/2020, je rajoute les paraètres fixes
+            
             
             errorsigncpt <- errorsigncpt + replicate.CI-nrow(partot)
             
+            if (!is.na(x$par["S"])) {
             # Je retire quand S change de signe
             # Là je ne le retire pas mais je l'inverse !
             if (any(sign(par[, "S"]) != sign(x$par["S"]))) {
               errorsignS <- errorsignS + sum(sign(par[, "S"]) != sign(x$par["S"]))
               par <- par[sign(par[, "S"]) == sign(x$par["S"]), , drop = FALSE]
             }
+            }
+            
+            if (!is.na(x$par["S_low"])) {
+              # Je retire quand S change de signe
+              # Là je ne le retire pas mais je l'inverse !
+              if (any(sign(par[, "S_low"]) != sign(x$par["S_low"]))) {
+                errorsignS_low <- errorsignS_low + sum(sign(par[, "S_low"]) != sign(x$par["S_low"]))
+                par <- par[sign(par[, "S_low"]) == sign(x$par["S_low"]), , drop = FALSE]
+              }
+            }
+            
+            if (!is.na(x$par["S_high"])) {
+              # Je retire quand S change de signe
+              # Là je ne le retire pas mais je l'inverse !
+              if (any(sign(par[, "S_high"]) != sign(x$par["S_high"]))) {
+                errorsignS_high <- errorsignS_high + sum(sign(par[, "S_high"]) != sign(x$par["S_high"]))
+                par <- par[sign(par[, "S_high"]) == sign(x$par["S_high"]), , drop = FALSE]
+              }
+            }
             
             # Le K est forcément A-symmetrical, donc le pivot est 0
             if (!is.na(x$par["K"])) {
@@ -139,7 +203,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
                 }
               }
             }
-
+            
             # K1 et K2 sont forcément de flexit, donc le pivot est 1
             if (!is.na(x$par["K1"])) {
               if (nrow(par) != 0) {
@@ -150,6 +214,27 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
               }
             }
             
+            # K1 et K2 sont forcément de flexit, donc le pivot est 1
+            if (!is.na(x$par["K1_low"])) {
+              if (nrow(par) != 0) {
+                if (any(sign(par[, "K1_low"] - 1) != sign(x$par["K1_low"] - 1))) {
+                  errorsignK1_low <- errorsignK1_low + sum(sign(par[, "K1_low"] - 1) != sign(x$par["K1_low"] - 1))
+                  par <- par[sign(par[, "K1_low"] - 1) == sign(x$par["K1_low"] - 1), , drop = FALSE]
+                }
+              }
+            }
+            
+            # K1 et K2 sont forcément de flexit, donc le pivot est 1
+            if (!is.na(x$par["K1_high"])) {
+              if (nrow(par) != 0) {
+                if (any(sign(par[, "K1_high"] - 1) != sign(x$par["K1_high"] - 1))) {
+                  errorsignK1_high <- errorsignK1_high + sum(sign(par[, "K1_high"] - 1) != sign(x$par["K1_high"] - 1))
+                  par <- par[sign(par[, "K1_high"] - 1) == sign(x$par["K1_high"] - 1), , drop = FALSE]
+                }
+              }
+            }
+            
+            
             if (!is.na(x$par["K2"])) {
               if (nrow(par) != 0) {
                 if (any(sign(par[, "K2"] - 1) != sign(x$par["K2"] - 1))) {
@@ -159,6 +244,24 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
               }
             }
             
+            if (!is.na(x$par["K2_low"])) {
+              if (nrow(par) != 0) {
+                if (any(sign(par[, "K2_low"] - 1) != sign(x$par["K2_low"] - 1))) {
+                  errorsignK2_low <- errorsignK2_low + sum(sign(par[, "K2_low"] - 1) != sign(x$par["K2_low"] - 1))
+                  par <- par[sign(par[, "K2_low"] - 1) == sign(x$par["K2_low"] - 1), , drop = FALSE]
+                }
+              }
+            }
+            
+            if (!is.na(x$par["K2_high"])) {
+              if (nrow(par) != 0) {
+                if (any(sign(par[, "K2_high"] - 1) != sign(x$par["K2_high"] - 1))) {
+                  errorsignK2_high <- errorsignK2_high + sum(sign(par[, "K2_high"] - 1) != sign(x$par["K2_high"] - 1))
+                  par <- par[sign(par[, "K2_high"] - 1) == sign(x$par["K2_high"] - 1), , drop = FALSE]
+                }
+              }
+            }
+            
             
             if (nrow(par) != 0) {
               partot <- rbind(partot, par)
@@ -166,6 +269,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
             if (nrow(partot) == replicate.CI) break
           }
           
+          
           if (warn) {
             if (errorsignK != 0) {
               message(paste("SE for K too high in", errorsignK, "cases out of", errorsigncpt))
@@ -173,13 +277,37 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
             if (errorsignS != 0) {
               message(paste("SE for S too high in", errorsignS, "cases out of", errorsigncpt))
             }
+            if (errorsignS_low != 0) {
+              message(paste("SE for S_low too high in", errorsignS_low, "cases out of", errorsigncpt))
+            }
+            if (errorsignS_high != 0) {
+              message(paste("SE for S_high too high in", errorsignS_high, "cases out of", errorsigncpt))
+            }
+            
             if (errorsignK1 != 0) {
               message(paste("SE for K1 too high in", errorsignK1, "cases out of", errorsigncpt))
             }
+            if (errorsignK1_low != 0) {
+              message(paste("SE for K1_low too high in", errorsignK1_low, "cases out of", errorsigncpt))
+            }
+            
+            if (errorsignK1_high != 0) {
+              message(paste("SE for K1 too high in", errorsignK1_high, "cases out of", errorsigncpt))
+            }
+            
             if (errorsignK2 != 0) {
               message(paste("SE for K2 too high in", errorsignK2, "cases out of", errorsigncpt))
             }
-            if ((errorsignK + errorsignK2 + errorsignK1 + errorsignS) != 0) {
+            if (errorsignK2_low != 0) {
+              message(paste("SE for K2_low too high in", errorsignK2_low, "cases out of", errorsigncpt))
+            }
+            if (errorsignK2_high != 0) {
+              message(paste("SE for K2_high too high in", errorsignK2_high, "cases out of", errorsigncpt))
+            }
+            
+            
+            if ((errorsignK + errorsignK2 + errorsignK1 + errorsignS  + errorsignS_low +  + errorsignS_high +
+                 errorsignK2_low + errorsignK1_low + errorsignK2_high + errorsignK2_low) != 0) {
               warning("Use results with caution; it is probably better to use MCMC")
             }
           }
@@ -191,19 +319,30 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
           # }
         } else {
           warning("The package lmf is required to estimate confidence interval.")
-          par <- t(as.matrix(x$par))
+          par <- matrix(x$par, nrow = 1)
+          colnames(par) <- names.par
         }
       } else {
-        par <- t(as.matrix(x$par))
+        par <- matrix(x$par, nrow = 1)
+        colnames(par) <- names.par
       }
       
     } else {
-      if (class(x)=="numeric") {
-        par <- t(as.matrix(x))
+      if (any(class(x)=="numeric")) {
+        names.par <- names(x)
+        par <- matrix(x$par, nrow = 1)
+        colnames(par) <- names.par
       }
     }
   }
   
+  if (!is.null(fixed.parameters)) {
+    mafp <- matrix(data = rep(fixed.parameters, nrow(par)), nrow = nrow(par), byrow = TRUE)
+    par <- cbind(par, mafp)
+    colnames(par) <- c(names.par, names(fixed.parameters))
+  }
+  
+  
   if (is.null(par))  stop("I don't understand the format of x parameter")
   
   # print(equation)
@@ -251,14 +390,31 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
         # (1/l) - 1 <- exp(1/S)(P-T)
         # log((1/l)-1) <- (1/S)(P-T)
         # log((1/l)-1)*S <- P-T
+        if (is.na(xpar["P_low"])) {
         limit.low.TRT <- unname(xpar["P"]-log((1/l)-1)*xpar["S"])
         limit.high.TRT <- unname(xpar["P"]-log((1/(1-l))-1)*xpar["S"])
         outr <- c(lower.limit.TRT=unname(min(c(limit.low.TRT, limit.high.TRT))), 
                   higher.limit.TRT=unname(max(c(limit.low.TRT, limit.high.TRT))), 
                   TRT=unname(abs(limit.high.TRT-limit.low.TRT)), 
                   PT=unname(xpar["P"]))
+        } else {
+          limit.low.TRT_low <- unname(xpar["P_low"]-log((1/l)-1)*xpar["S_low"])
+          limit.high.TRT_low <- unname(xpar["P_low"]-log((1/(1-l))-1)*xpar["S_low"])
+          limit.low.TRT_high <- unname(xpar["P_high"]-log((1/l)-1)*xpar["S_high"])
+          limit.high.TRT_high <- unname(xpar["P_high"]-log((1/(1-l))-1)*xpar["S_high"])
+          outr <- c(lower.limit.TRT_low=unname(min(c(limit.low.TRT_low, limit.high.TRT_low))), 
+                    higher.limit.TRT_low=unname(max(c(limit.low.TRT_low, limit.high.TRT_low))), 
+                    TRT_low=unname(abs(limit.high.TRT_low-limit.low.TRT_low)), 
+                    PT_low=unname(xpar["P_low"]), 
+                    lower.limit.TRT_high=unname(min(c(limit.low.TRT_high, limit.high.TRT_high))), 
+                    higher.limit.TRT_high=unname(max(c(limit.low.TRT_high, limit.high.TRT_high))), 
+                    TRT_high=unname(abs(limit.high.TRT_high-limit.low.TRT_high)), 
+                    PT_high=unname(xpar["P_high"]))
+          
+        }
       }
       if (equation=="flexit") {
+        if (!is.na(xpar["P"])) {
         P <- xpar["P"]
         S <- xpar["S"]
         K1 <- xpar["K1"]
@@ -313,13 +469,127 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
                   higher.limit.TRT=unname(limit.high.TRT), 
                   TRT=unname(limit.high.TRT-limit.low.TRT), 
                   PT=unname(P))
+        } else {
+          # Modèle TSD II ou FMF
+          P <- xpar["P_low"]
+          S <- xpar["S_low"]
+          K1 <- xpar["K1_low"]
+          K2 <- xpar["K2_low"]
+          
+          if (K1 == 0) {
+            K1 <- 1e-9
+          }
+          if (K2 == 0) {
+            K2 <- 1e-9
+          }
+          
+          if (is.infinite(2^(K1))) {
+            S1 <- K1*S
+            K1 <- sign(K1)*500
+          } else {
+            S1 <- (2^(K1 - 1)*K1*S)/(2^(K1) - 1)
+          }
+          
+          
+          if (is.infinite(2^(K2))) {
+            S2 <- K2*S
+            K2 <- sign(K2)*500
+          } else {
+            S2 <- (2^(K2 - 1)*K2*S)/(2^(K2) - 1)
+          }
+          
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(-1/K1)) = (1-l)
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(1/K1)) = 1/(1-l)
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x))) = (1/(1-l)) ^ K1
+          # (2^K1 - 1) *  exp(4 * S1 * (P - x)) = (1/(1-l)) ^ K1 - 1
+          # exp(4 * S1 * (P - x)) = ((1/(1-l)) ^ K1 - 1)/(2^K1 - 1)
+          # 4 * S1 * (P - x) = log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))
+          # P - x = log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          # x= P -  log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          
+          limit.low.TRT_low <- P -  log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          
+          # 1-(1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2) = l
+          # (1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2) = (1-l)
+          # (1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(1/K2) = 1/(1-l)
+          # 1 + (2^K2 - 1) * exp(4 * S2 * (x - P)) = (1/(1-l))^K2
+          # (2^K2 - 1) * exp(4 * S2 * (x - P)) = (1/(1-l))^K2 - 1
+          # exp(4 * S2 * (x - P)) = ((1/(1-l))^K2 - 1)/(2^K2 - 1)
+          # 4 * S2 * (x - P)) = log(((1/(1-l))^K2 - 1)/(2^K2 - 1))
+          # x - P = 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1))
+          # x = 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1)) + P
+          
+          limit.high.TRT_low <- 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1)) + P
+          
+          P <- xpar["P_high"]
+          S <- xpar["S_high"]
+          K1 <- xpar["K1_high"]
+          K2 <- xpar["K2_high"]
+          
+          if (K1 == 0) {
+            K1 <- 1e-9
+          }
+          if (K2 == 0) {
+            K2 <- 1e-9
+          }
+          
+          if (is.infinite(2^(K1))) {
+            S1 <- K1*S
+            K1 <- sign(K1)*500
+          } else {
+            S1 <- (2^(K1 - 1)*K1*S)/(2^(K1) - 1)
+          }
+          
+          
+          if (is.infinite(2^(K2))) {
+            S2 <- K2*S
+            K2 <- sign(K2)*500
+          } else {
+            S2 <- (2^(K2 - 1)*K2*S)/(2^(K2) - 1)
+          }
+          
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(-1/K1)) = (1-l)
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x)))^(1/K1)) = 1/(1-l)
+          # (1 + (2^K1 - 1) *  exp(4 * S1 * (P - x))) = (1/(1-l)) ^ K1
+          # (2^K1 - 1) *  exp(4 * S1 * (P - x)) = (1/(1-l)) ^ K1 - 1
+          # exp(4 * S1 * (P - x)) = ((1/(1-l)) ^ K1 - 1)/(2^K1 - 1)
+          # 4 * S1 * (P - x) = log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))
+          # P - x = log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          # x= P -  log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          
+          limit.low.TRT_high <- P -  log(((1/(1-l)) ^ K1 - 1)/(2^K1 - 1))/(4 * S1)
+          
+          # 1-(1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2) = l
+          # (1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(-1/K2) = (1-l)
+          # (1 + (2^K2 - 1) * exp(4 * S2 * (x - P)))^(1/K2) = 1/(1-l)
+          # 1 + (2^K2 - 1) * exp(4 * S2 * (x - P)) = (1/(1-l))^K2
+          # (2^K2 - 1) * exp(4 * S2 * (x - P)) = (1/(1-l))^K2 - 1
+          # exp(4 * S2 * (x - P)) = ((1/(1-l))^K2 - 1)/(2^K2 - 1)
+          # 4 * S2 * (x - P)) = log(((1/(1-l))^K2 - 1)/(2^K2 - 1))
+          # x - P = 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1))
+          # x = 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1)) + P
+          
+          limit.high.TRT_high <- 1/(4 * S2) * log(((1/(1-l))^K2 - 1)/(2^K2 - 1)) + P
+          
+          outr <- c(lower.limit.TRT_low=unname(min(c(limit.low.TRT_low, limit.high.TRT_low))), 
+                    higher.limit.TRT_low=unname(max(c(limit.low.TRT_low, limit.high.TRT_low))), 
+                    TRT_low=unname(abs(limit.high.TRT_low-limit.low.TRT_low)), 
+                    PT_low=unname(xpar["P_low"]), 
+                    lower.limit.TRT_high=unname(min(c(limit.low.TRT_high, limit.high.TRT_high))), 
+                    higher.limit.TRT_high=unname(max(c(limit.low.TRT_high, limit.high.TRT_high))), 
+                    TRT_high=unname(abs(limit.high.TRT_high-limit.low.TRT_high)), 
+                    PT_high=unname(xpar["P_high"]))
+          
+        }
+        
+        
       }
       
       if (equation=="a-logistic") {
         P <- xpar["P"]
         S <- xpar["S"]
         K <- xpar["K"]
-
+        
         # (1 + (2^exp(K) - 1) * exp((1/S) * (P - x)))^(-1/exp(K)) =  1 - l
         # (1 + (2^exp(K) - 1) * exp((1/S) * (P - x)))^(1/exp(K)) =  1/(1 - l)
         # 1 + (2^exp(K) - 1) * exp((1/S) * (P - x)) =  (1/(1 - l))^exp(K)
@@ -417,7 +687,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
       if (equation=="hill") {
         P <- xpar["P"]
         S <- xpar["S"]
-       
+        
         # 1/(1+exp((1/par["S"])*(log(par["P"])-log(temperatures)))) = 1 - l
         # 1+exp((1/par["S"])*(log(par["P"])-log(temperatures))) = 1 / (1 - l)
         # exp((1/par["S"])*(log(par["P"])-log(temperatures))) = (1 / (1 - l))-1
@@ -438,6 +708,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
       
       # Les autres modèles
       if (is.null(outr)) {
+        warning(paste0("TRT and PT estimations for the model ", equation," is not implemented."))
         outr <- c(lower.limit.TRT=NA, 
                   higher.limit.TRT=NA, 
                   TRT=NA, 
@@ -463,7 +734,7 @@ P_TRT <- function(x=NULL, resultmcmc=NULL, chain=1, equation=NULL, l=0.05,
       prsrT <- as.matrix(prsrT)
     } else {
       prsrT <- apply(t(srT), MARGIN = 2, function(xxx) quantile(xxx, probs = probs, na.rm = TRUE))
-      if (class(prsrT) == "numeric") {
+      if (any(class(prsrT) == "numeric")) {
         prsrT <- matrix(prsrT, nrow = 1)
         rownames(prsrT) <- paste0(as.character(probs*100), "%")
       }
