@@ -26,8 +26,8 @@
   
   if (any(nm=="Dallwitz_b1")) {
     
-    if (is.na(parms["Dallwitz_b4"])) parms <- c(parms, Dallwitz_b4 = 6, Dallwitz_b5 =0.4)
-    
+    if (is.na(parms["Dallwitz_b4"])) parms <- c(parms, Dallwitz_b4 = 6)
+    if (is.na(parms["Dallwitz_b5"])) parms <- c(parms, Dallwitz_b5 =0.4)
     T <- T - 273.15
     c1 <- 1/(1+0.28*parms["Dallwitz_b4"]+0.72*log(1+parms["Dallwitz_b4"]))
     c2 <- 1+parms["Dallwitz_b4"]/(1+1.5*parms["Dallwitz_b4"]+0.39*parms["Dallwitz_b4"]^2)
@@ -168,8 +168,6 @@
       if (is.na(parms["Rho25_b"])) {rho25_b <- 0} else {rho25_b <- parms["Rho25_b"]/1E7}
       
       R <- 8.314472
-      epsilon <- parms["epsilon"]/1E7
-      if (is.na(epsilon)) epsilon <- 0
       rho25 <- parms["Rho25"]/1E7
       dha <- parms["DHA"]*1E3
       dhh <- parms["DHH"]*1E3
@@ -180,14 +178,14 @@
         # Je suis en 4 parametres
         #	"T12H", "DHA",  "DHH", "Rho25"
         t12H=abs(parms["T12H"])
-        rT<-( (rho25 + rho25_b*H) * (T/298)*exp((dha/R)*(unsur298-unsurT)))/(1+exp((dhh/R)*((1/t12H)-unsurT)))+epsilon
+        rT<-( (rho25 + rho25_b*H) * (T/298)*exp((dha/R)*(unsur298-unsurT)))/(1+exp((dhh/R)*((1/t12H)-unsurT)))
       } else {
         # 28/7/2012 - T12H change en DT	
         #	"T12L", "DT", "DHA",  "DHH", "DHL", "Rho25"
         dhl <- parms["DHL"]*1E3
         t12L <- parms["T12L"]
         t12H <- t12L+abs(parms["DT"])
-        rT<-((rho25 + rho25_b*H)*(T/298)*exp((dha/R)*(unsur298-unsurT)))/(1+exp((dhl/R)*((1/t12L)-unsurT))+exp((dhh/R)*((1/t12H)-unsurT)))+epsilon
+        rT<-((rho25 + rho25_b*H)*(T/298)*exp((dha/R)*(unsur298-unsurT)))/(1+exp((dhl/R)*((1/t12L)-unsurT))+exp((dhh/R)*((1/t12H)-unsurT)))
       }
       
       if (!is.na(parms["Rho25_L"])) {
@@ -201,14 +199,14 @@
         if (is.na(parms["DHL_L"])) {
           #	"T12H", "DHA",  "DHH", "Rho25"
           t12H_L <- abs(parms["T12H_L"])
-          rT_L <- ((rho25_L + rho25_b_L*H)*(T/298)*exp((dha_L/R)*(unsur298-unsurT)))/(1+exp((dhh_L/R)*((1/t12H_L)-unsurT)))+epsilon
+          rT_L <- ((rho25_L + rho25_b_L*H)*(T/298)*exp((dha_L/R)*(unsur298-unsurT)))/(1+exp((dhh_L/R)*((1/t12H_L)-unsurT)))
         } else {
           # 28/7/2012 - T12H change en DT	
           #	"T12L", "T12H", "DHA",  "DHH", "DHL", "Rho25"
           dhl_L <- parms["DHL_L"]*1E3
           t12L_L <- parms["T12L_L"]
           t12H_L <- t12L+abs(parms["DT_L"])
-          rT_L <- ((rho25_L + rho25_b_L*H)*(T/298)*exp((dha_L/R)*(unsur298-unsurT)))/(1+exp((dhl_L/R)*((1/t12L_L)-unsurT))+exp((dhh_L/R)*((1/t12H_L)-unsurT)))+epsilon
+          rT_L <- ((rho25_L + rho25_b_L*H)*(T/298)*exp((dha_L/R)*(unsur298-unsurT)))/(1+exp((dhl_L/R)*((1/t12L_L)-unsurT))+exp((dhh_L/R)*((1/t12H_L)-unsurT)))
         }
       } else {
         rT_L <- rT
@@ -217,8 +215,12 @@
     }
   }
     
+  epsilon <- parms["epsilon"]/1E7
+  if (is.na(epsilon)) epsilon <- 0
+  epsilon_L <- parms["epsilon_L"]/1E7
+  if (is.na(epsilon_L)) epsilon_L <- 0
   
-  return(list(as.numeric(rT), as.numeric(rT_L)))
+  return(list(unname(rT+epsilon), unname(rT_L+epsilon_L)))
   
 }
 
