@@ -6,6 +6,9 @@ return(getFromNamespace(".STRN_fit", ns="embryogrowth")(par=x,
                  fixed.parameters=data$fixed.parameters, 
                  EmbryoGrowthTRN=data$EmbryoGrowthTRN, 
                  embryo.stages=data$embryo.stages, 
+                 TSP.borders=data$TSP.borders, 
+                 TSP.begin=data$TSP.begin, 
+                 TSP.end=data$TSP.end, 
                  tsd=data$tsd, 
                  zero=data$zero, 
                 Sexed=data$Sexed, Males=data$Males, 
