@@ -128,12 +128,12 @@ plotR <-
     
     SSM <- getFromNamespace(".SSM", ns="embryogrowth")
     
-    if (class(result)=="mcmcComposite") {
+    if (any(class(result)=="mcmcComposite")) {
       resultmcmc <- result
       result <- NULL
     }
     
-    if (class(result)=="numeric") {
+    if (any(class(result)=="numeric")) {
       parameters <- result
       result <- NULL
     }
@@ -142,8 +142,8 @@ plotR <-
     if (is.null(fixed.parameters) & !is.null(result)) fixed.parameters <- result$fixed.parameters
     if (is.null(parameters) & !is.null(result)) parameters <- result$par
     
-#    parameters <- c(parameters, fixed.parameters)
-#    if (is.null(parameters) & !is.null(result)) parameters <- c(result$par, result$fixed.parameters)
+    #    parameters <- c(parameters, fixed.parameters)
+    #    if (is.null(parameters) & !is.null(result)) parameters <- c(result$par, result$fixed.parameters)
     if (is.null(parameters) & !is.null(resultmcmc)) parameters <- suppressMessages(as.parameters(resultmcmc))
     
     if (is.null(temperatures) & !is.null(result)) temperatures <- result$data
@@ -158,15 +158,15 @@ plotR <-
       show.hist <- FALSE
     }
     
-      if (is.null(mar)) {
-        if (!is.null(result) & show.hist & new) {
-          par(mar=c(4, 4, 1, 4)+0.4) 
-        } else {
-          par(mar=c(4, 4, 4, 1)+0.4)
-        }
+    if (is.null(mar)) {
+      if (!is.null(result) & show.hist & new) {
+        par(mar=c(4, 4, 1, 4)+0.4) 
       } else {
-        if (all(!is.na(mar))) par(mar=mar)
+        par(mar=c(4, 4, 4, 1)+0.4)
       }
+    } else {
+      if (all(!is.na(mar))) par(mar=mar)
+    }
     
     temp <- seq(from=xlim[1], to=xlim[2], by=by.temperature)
     
@@ -176,24 +176,24 @@ plotR <-
     xxw_ML <- NULL
     
     if (!is.null(resultmcmc) & (show.density | curves=="mcmc quantiles" | curves=="mcmc mean-sd")) {
-    dataR <- resultmcmc$resultMCMC[[1]]
-    xxw <- matrix(ncol = 2, 
-                  nrow = length(temp)*nrow(dataR))
-    xxw2 <- matrix(data = as.numeric(), ncol = length(temp), 
-                   nrow = nrow(dataR))
-    
-    xxw[, 1] <- rep(temp, nrow(dataR))
-    for (i in 1:nrow(dataR)) {
-      r <- SSM(T=temp, 
-               parms=c(dataR[i,], fixed.parameters))[[set.par]]
-      jhn <- (1+(i-1)*length(temp)):((i-1)*length(temp)+length(temp))
-      # xxw[jhn, 1] <- temp
-      xxw[jhn, 2] <- r
-      xxw2[i, ] <- r
-    }
-    rxxw <- apply(xxw2, MARGIN = 2, 
-                  FUN = function(x) c(Mean=mean(x), sd=sd(x), quantile(x, probs =c((1-probs)/2, 0.5, 1-(1-probs)/2), na.rm=TRUE)))
-    rxxw <- rbind(temperatures=temp, rxxw)
+      dataR <- resultmcmc$resultMCMC[[1]]
+      xxw <- matrix(ncol = 2, 
+                    nrow = length(temp)*nrow(dataR))
+      xxw2 <- matrix(data = as.numeric(), ncol = length(temp), 
+                     nrow = nrow(dataR))
+      
+      xxw[, 1] <- rep(temp, nrow(dataR))
+      for (i in 1:nrow(dataR)) {
+        r <- SSM(T=temp, 
+                 parms=c(dataR[i,], fixed.parameters))[[set.par]]
+        jhn <- (1+(i-1)*length(temp)):((i-1)*length(temp)+length(temp))
+        # xxw[jhn, 1] <- temp
+        xxw[jhn, 2] <- r
+        xxw2[i, ] <- r
+      }
+      rxxw <- apply(xxw2, MARGIN = 2, 
+                    FUN = function(x) c(Mean=mean(x), sd=sd(x), quantile(x, probs =c((1-probs)/2, 0.5, 1-(1-probs)/2), na.rm=TRUE)))
+      rxxw <- rbind(temperatures=temp, rxxw)
     }
     
     if (curves=="ml quantiles" & is.null(hessian)) {
@@ -204,37 +204,37 @@ plotR <-
     # j'ai un hessian qui est fourni
     if (curves=="ml quantiles" & !is.null(hessian)) {
       
-
+      
       Scoefs <- parameters
-#      hessian <- result$hessian
+      #      hessian <- result$hessian
       # rownames(hessian) <- colnames(hessian) <- names(Scoefs)
       
-
+      
       
       rxxw_ML <- data.frame(temperatures = numeric(), 
                             Mean=numeric(), sd=numeric(), 
-                            "2.5%" = numeric(), 
-                            "50%" = numeric(), 
-                            "97.5%" = numeric()) 
+                            "X2.5" = numeric(), 
+                            "X50" = numeric(), 
+                            "X97.5" = numeric()) 
       
       txt <- paste0("getFromNamespace('.wrapperSSM', ns='embryogrowth')(", 
-      paste0("b[", 1:length(Scoefs), "], ", collapse=""), 
-      ifelse(length(fixed.parameters)>0, 
-      paste0("x[1]", ", x[", 2:(1+length(fixed.parameters)), "] ", collapse=""), 
-      paste0("x[1]")), 
-      ")", collapse="")
-    warn <- FALSE
+                    paste0("b[", 1:length(Scoefs), "], ", collapse=""), 
+                    ifelse(length(fixed.parameters)>0, 
+                           paste0("x[1]", ", x[", 2:(1+length(fixed.parameters)), "] ", collapse=""), 
+                           paste0("x[1]")), 
+                    ")", collapse="")
+      warn <- FALSE
       for (temperature in temp) {
         options(warn=2) 
         # if it returns an error, it means that CI is too small to be estimated
-        ic5 <- try(getFromNamespace(".nlConfint", ns="HelpersMG")(texts=txt, 
-                                              level = probs, coeff = Scoefs,
-                                              Vcov = solve(hessian), df2 = TRUE, 
-                                              x = c(T=temperature, fixed.parameters), 
-                                              silent=TRUE), silent=TRUE)
+        ic5 <- try(getFromNamespace(".nlConfint", ns="HelpersMG")(obj=NULL, texts=txt, 
+                                                                  level = probs, coeff = Scoefs,
+                                                                  Vcov = solve(hessian), df2 = TRUE, 
+                                                                  x = c(T=temperature, fixed.parameters), 
+                                                                  silent=TRUE), silent=TRUE)
         options(warn=0)
         vy <- getFromNamespace('.wrapperSSM', ns='embryogrowth')(c(Scoefs, fixed.parameters, T=temperature))
-        if (class(ic5) == "try-error") {
+        if (any(class(ic5) == "try-error")) {
           # L'inervalle de confiance est nul ou autre probleme dans le genre
           # warning(ic5)
           warn <- TRUE
@@ -249,9 +249,9 @@ plotR <-
           rxxw_ML <- rbind(rxxw_ML, 
                            data.frame(temperatures=temperature, 
                                       Mean = vy, sd = NA, 
-                                      "2.5%" = ic5[1, 2], 
-                                      "50%" = vy, 
-                                      "97.5%" = ic5[1, 3]))
+                                      "X2.5" = ic5[1, 2], 
+                                      "X50" = ic5[1, 1], 
+                                      "X97.5" = ic5[1, 3]))
         }
       }
       if (warn) {
@@ -287,18 +287,18 @@ plotR <-
           xxw2[i, ] <- r
         }
         rxxw_ML <- apply(xxw2, MARGIN = 2, 
-                      FUN = function(x) c(Mean=mean(x), sd=sd(x), quantile(x, probs =c((1-probs)/2, 0.5, 1-(1-probs)/2), na.rm=TRUE)))
+                         FUN = function(x) c(Mean=mean(x), sd=sd(x), quantile(x, probs =c((1-probs)/2, 0.5, 1-(1-probs)/2), na.rm=TRUE)))
         rxxw_ML <- t(rbind(temperatures=temp, rxxw_ML))
       }
-    rxxw_ML <- as.matrix(t(rxxw_ML))
+      rxxw_ML <- as.matrix(t(rxxw_ML))
     }
     
-      
+    
     # Si je n'ai pas de tableau generes, je les mets a NA
     if (is.null(rxxw))
-          rxxw <- as.matrix(t(data.frame(temperatures=temp, Mean=NA, sd=NA, "2.5%"=NA, "50%"=NA, "97.5%"=NA)))
+      rxxw <- as.matrix(t(data.frame(temperatures=temp, Mean=NA, sd=NA, "X2.5"=NA, "X50"=NA, "X97.5"=NA)))
     if (is.null(rxxw_ML))
-          rxxw_ML <- as.matrix(t(data.frame(temperatures=temp, Mean=NA, sd=NA, "2.5%"=NA, "50%"=NA, "97.5%"=NA)))
+      rxxw_ML <- as.matrix(t(data.frame(temperatures=temp, Mean=NA, sd=NA, "X2.5"=NA, "X50"=NA, "X97.5"=NA)))
     
     
     if (!is.null(c(parameters, fixed.parameters))) {
@@ -328,15 +328,15 @@ plotR <-
     if (show.density & !is.null(xxw)) {
       if (new) {
         par(new=FALSE)
-    smoothScatter(x=xxw[, 1], y=xxw[, 2], las=las, bty = bty,  pch=pch, 
-                  bandwidth = bandwidth, 
-                  xlab=xlab, 
-                  main=main,
-                  colramp=colramp, 
-                  ylab=ylab, 
-                  ylim=ylim, xlim = xlim, nbin = 128, postPlotHook=NULL, 
-                  cex.axis=cex.axis, 
-                  cex.lab=cex.lab)
+        smoothScatter(x=xxw[, 1], y=xxw[, 2], las=las, bty = bty,  pch=pch, 
+                      bandwidth = bandwidth, 
+                      xlab=xlab, 
+                      main=main,
+                      colramp=colramp, 
+                      ylab=ylab, 
+                      ylim=ylim, xlim = xlim, nbin = 128, postPlotHook=NULL, 
+                      cex.axis=cex.axis, 
+                      cex.lab=cex.lab)
       } else {
         par(new=TRUE)
         smoothScatter(x=xxw[, 1], y=xxw[, 2], bty = "n",  pch=pch, 
@@ -356,31 +356,31 @@ plotR <-
     } else {
       if (new) {
         par(new=FALSE)
-      plot(xxw[, 1], y=xxw[, 2], type="n", 
-           las=las, 
-           bty = bty, 
-           xlab=xlab, 
-           main=main,
-           ylab=ylab, 
-           ylim=ylim, 
-           xlim = xlim, 
-           cex.axis=cex.axis, 
-           cex.lab=cex.lab)
-      # } else {
-      #   par(new=TRUE)
-      #   plot(xxw[, 1], y=xxw[, 2], type="n", 
-      #        las=las, 
-      #        bty = bty, 
-      #        xlab="", 
-      #        main="",
-      #        ylab="", 
-      #        ylim = ScalePreviousPlot()$ylim[1:2], 
-      #        xlim = ScalePreviousPlot()$xlim[1:2], 
-      #        axes=FALSE)
+        plot(xxw[, 1], y=xxw[, 2], type="n", 
+             las=las, 
+             bty = bty, 
+             xlab=xlab, 
+             main=main,
+             ylab=ylab, 
+             ylim=ylim, 
+             xlim = xlim, 
+             cex.axis=cex.axis, 
+             cex.lab=cex.lab)
+        # } else {
+        #   par(new=TRUE)
+        #   plot(xxw[, 1], y=xxw[, 2], type="n", 
+        #        las=las, 
+        #        bty = bty, 
+        #        xlab="", 
+        #        main="",
+        #        ylab="", 
+        #        ylim = ScalePreviousPlot()$ylim[1:2], 
+        #        xlim = ScalePreviousPlot()$xlim[1:2], 
+        #        axes=FALSE)
       }
     }
     
-
+    
     vx <- c(rxxw["temperatures", ], rev(rxxw["temperatures", ]))
     
     if (any(curves == "mcmc quantiles") & any(!is.na(rxxw[c("X2.5", "X50", "X97.5"), ]))) {
@@ -391,17 +391,17 @@ plotR <-
         polygon(x=vx, y=vy, col=col.polygon, border = NA)
       }
       
-    dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X50", ]>=ylim[1] & rxxw["X50", ]<=ylim[2], rxxw["X50", ], NA))
-    dxy <- na.omit(dxy)
-    lines(x = dxy$x, y=dxy$y, lty=lty, lwd=lwd, col=col)
-    
-    dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X2.5", ]>=ylim[1] & rxxw["X2.5", ]<=ylim[2], rxxw["X2.5", ], NA))
-    dxy <- na.omit(dxy)
-    lines(x = dxy$x, y=dxy$y, lty=ltyCI, lwd=lwdCI, col=col)
-    
-    dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X97.5", ]>=ylim[1] & rxxw["X97.5", ]<=ylim[2], rxxw["X97.5", ], NA))
-    dxy <- na.omit(dxy)
-    lines(x = dxy$x, y=dxy$y, lty=ltyCI, lwd=lwdCI, col=col)
+      dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X50", ]>=ylim[1] & rxxw["X50", ]<=ylim[2], rxxw["X50", ], NA))
+      dxy <- na.omit(dxy)
+      lines(x = dxy$x, y=dxy$y, lty=lty, lwd=lwd, col=col)
+      
+      dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X2.5", ]>=ylim[1] & rxxw["X2.5", ]<=ylim[2], rxxw["X2.5", ], NA))
+      dxy <- na.omit(dxy)
+      lines(x = dxy$x, y=dxy$y, lty=ltyCI, lwd=lwdCI, col=col)
+      
+      dxy <- data.frame(x=rxxw["temperatures", ], y=ifelse(rxxw["X97.5", ]>=ylim[1] & rxxw["X97.5", ]<=ylim[2], rxxw["X97.5", ], NA))
+      dxy <- na.omit(dxy)
+      lines(x = dxy$x, y=dxy$y, lty=ltyCI, lwd=lwdCI, col=col)
     }
     
     if (any(curves == "mcmc mean-sd") & any(!is.na(rxxw[c("Mean", "sd"), ]))) {
@@ -452,37 +452,37 @@ plotR <-
     }
     
     if (!is.null(temperatures) & show.hist) {
-    
-    xlim <- ScalePreviousPlot()$xlim[c("begin", "end")]
-    ylim <- ScalePreviousPlot()$ylim[c("begin", "end")]
-    
-    par(new=TRUE)
-    if (log.hist==FALSE) {
-     if (is.null(ylimH)) {
-       a <- hist(x=temperatures, xlab="", ylab="", main="", axes=FALSE, freq=FALSE, 
-                            xlim=xlim, breaks=breaks)
+      
+      xlim <- ScalePreviousPlot()$xlim[c("begin", "end")]
+      ylim <- ScalePreviousPlot()$ylim[c("begin", "end")]
+      
+      par(new=TRUE)
+      if (log.hist==FALSE) {
+        if (is.null(ylimH)) {
+          a <- hist(x=temperatures, xlab="", ylab="", main="", axes=FALSE, freq=FALSE, 
+                    xlim=xlim, breaks=breaks)
+        } else {
+          a <- hist(x=temperatures, xlab="", ylab="", main="", axes=FALSE, freq=FALSE, 
+                    xlim=xlim, ylim=ylimH, breaks=breaks)
+        }
+        axis(side=4, las=1, at=atH, cex.axis=cex.axis)
+        
       } else {
-        a <- hist(x=temperatures, xlab="", ylab="", main="", axes=FALSE, freq=FALSE, 
-                  xlim=xlim, ylim=ylimH, breaks=breaks)
-      }
-      axis(side=4, las=1, at=atH, cex.axis=cex.axis)
-      
-    } else {
-      ax <- hist(x=temperatures, plot=FALSE)
-      yi <- ifelse(log(ax$histogram$density*1000)<0, 0, log(ax$histogram$density*1000))
-      myi <- max(yi)
-      yi <- yi/myi
-      if (!is.null(ylimH)) yi <- yi*ylimH[2]
-      
-      yi <- yi*ylim[2]
-      
-      for (i in seq_along(ax$histogram$density)) {
-        polygon(x=ax$histogram$breaks[c(i, i+1, i+1, i)], y=c(0, 0, yi[i], yi[i]))
-      }
-      
-      if (is.null(atH)) {
-        atH <- seq(from=0, to=max(ax$histogram$density), by=0.05)
-      } 
+        ax <- hist(x=temperatures, plot=FALSE)
+        yi <- ifelse(log(ax$histogram$density*1000)<0, 0, log(ax$histogram$density*1000))
+        myi <- max(yi)
+        yi <- yi/myi
+        if (!is.null(ylimH)) yi <- yi*ylimH[2]
+        
+        yi <- yi*ylim[2]
+        
+        for (i in seq_along(ax$histogram$density)) {
+          polygon(x=ax$histogram$breaks[c(i, i+1, i+1, i)], y=c(0, 0, yi[i], yi[i]))
+        }
+        
+        if (is.null(atH)) {
+          atH <- seq(from=0, to=max(ax$histogram$density), by=0.05)
+        } 
         
         yi <- ifelse(log(atH*1000)<0, 0, log(atH*1000))
         # myi <- max(yi)
@@ -492,16 +492,16 @@ plotR <-
         yi <- yi*ylim[2]
         
         axis(side=4, las=1, at=yi, labels = atH, cex.axis=cex.axis)
-      
+        
         atH <- yi
-    }
-    
-    mtext(ylabH, side=4, line=3, at=ifelse(is.null(atH), NA, mean(c(atH[1], rev(atH)[1]))), cex=cex.lab)
-    
-    par(new=TRUE)
-    # je retablis l'echelle des y et celle de R
-    plot(x = 1, y=1, ylim=ylim, xlim=xlim, xlab="", ylab="", axes=FALSE, bty="n", type="n")
-    
+      }
+      
+      mtext(ylabH, side=4, line=3, at=ifelse(is.null(atH), NA, mean(c(atH[1], rev(atH)[1]))), cex=cex.lab)
+      
+      par(new=TRUE)
+      # je retablis l'echelle des y et celle de R
+      plot(x = 1, y=1, ylim=ylim, xlim=xlim, xlab="", ylab="", axes=FALSE, bty="n", type="n")
+      
     }
     
     return(invisible(scaleY))
