@@ -8,7 +8,8 @@
 #' @param n.chains Number of replicates
 #' @param n.adapt Number of iterations before to store outputs
 #' @param thin Number of iterations between each stored output
-#' @param trace True or False, shows progress
+#' @param trace TRUE or FALSE or period, shows progress
+#' @param traceML TRUE or FALSE to show ML
 #' @param batchSize Number of observations to include in each batch fo SE estimation
 #' @param adaptive Should an adaptive process for SDProp be used
 #' @param adaptive.lag  Lag to analyze the SDProp value in an adaptive content
@@ -46,6 +47,9 @@
 #' summary(result_mcmc_tsd)
 #' plot(result_mcmc_tsd, parameters="S", scale.prior=TRUE, xlim=c(-3, 3), las=1)
 #' plot(result_mcmc_tsd, parameters="P", scale.prior=TRUE, xlim=c(25, 35), las=1)
+#' 
+#' plot(eo_logistic, resultmcmc = result_mcmc_tsd)
+#' 
 #' 1-rejectionRate(as.mcmc(result_mcmc_tsd))
 #' raftery.diag(as.mcmc(result_mcmc_tsd))
 #' heidel.diag(as.mcmc(result_mcmc_tsd))
@@ -65,20 +69,29 @@
 #' lines(outEo[, 1], outEo[, 2], col="green", lwd=2)
 #' legend("topleft", legend = c("Emys orbicularis", "95% confidence ellipse"), 
 #'        pch=c(19, NA), col=c("black", "green"), lty=c(0, 1), lwd=c(0, 2))
-
-
+#'
+#' logistic <- function(x, P, S) {
+#'    return(1/(1+exp((1/S)*(P-x))))
+#' }
+#' 
+#' q <- as.quantile(result_mcmc_tsd, fun=logistic, 
+#'                  xlim=seq(from=25, to=35, by=0.1), nameparxlim="x")
+#' plot(x=seq(from=25, to=35, by=0.1), y=q[1, ], type="l", las=1, 
+#'      xlab="Temperatures", ylab="Male proportion", bty="n")
+#' lines(x=seq(from=25, to=35, by=0.1), y=q[2, ])
+#'
 #' }
 #' @export
 
 tsd_MHmcmc <- function(result=stop("A result of tsd() fit must be provided"), n.iter=10000, 
-parametersMCMC=NULL, n.chains = 1, n.adapt = 0, 
-thin=1, trace=FALSE, batchSize=sqrt(n.iter), 
-adaptive=FALSE, adaptive.lag=500, adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)},
-intermediate=NULL, filename="intermediate.Rdata", previous=NULL) {
-
-# result=eo_logistic; parametersMCMC=NULL; 
-# n.iter=10000; n.chains = 1;  n.adapt = 0; thin=1; trace=TRUE; batchSize=sqrt(n.iter);intermediate=NULL; filename="intermediate.Rdata"; previous=NULL; adaptive=FALSE; adaptive.lag=500; adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)}
-
+                       parametersMCMC=NULL, n.chains = 1, n.adapt = 0, 
+                       thin=1, trace=FALSE, traceML=FALSE, batchSize=sqrt(n.iter), 
+                       adaptive=FALSE, adaptive.lag=500, adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)},
+                       intermediate=NULL, filename="intermediate.Rdata", previous=NULL) {
+  
+  # result=eo_logistic; parametersMCMC=NULL; 
+  # n.iter=10000; n.chains = 1;  n.adapt = 0; thin=1; trace=TRUE; batchSize=sqrt(n.iter);intermediate=NULL; filename="intermediate.Rdata"; previous=NULL; adaptive=FALSE; adaptive.lag=500; adaptive.fun=function(x) {ifelse(x>0.234, 1.3, 0.7)}
+  
   if (is.character(previous)) {
     itr <- NULL
     load(previous)
@@ -89,40 +102,45 @@ intermediate=NULL, filename="intermediate.Rdata", previous=NULL) {
     print(parametersMCMC)
   }
   
-# 29/1/2014; Ajout de result$weight
+  # 29/1/2014; Ajout de result$weight
   # 30/1/2015 Ajout de fixedparameters
   out <- MHalgoGen(n.iter=n.iter, parameters=parametersMCMC, 
-                   n.chains = n.chains, n.adapt = n.adapt, thin=thin, trace=trace, 
+                   n.chains = n.chains, n.adapt = n.adapt, thin=thin, 
+                   trace=trace, traceML=traceML, 
                    males=result$males, N=result$N, temperatures=result$temperatures, 
-                             equation=result$equation, fixed.parameters=result$fixed.parameters, 
-                             likelihood=getFromNamespace(".fonctiontsdMCMC", ns="embryogrowth"), 
+                   equation=result$equation, fixed.parameters=result$fixed.parameters, 
+                   likelihood=getFromNamespace(".tsd_fit", ns="embryogrowth"), 
+                   parameters_name = "par", 
                    adaptive=adaptive, adaptive.lag=adaptive.lag, adaptive.fun=adaptive.fun,
-                             intermediate=intermediate, filename=filename, previous=previous)
-
-if (batchSize>=n.iter/2) {
-  print("batchSize cannot be larger than half the number of iterations.")
-  rese <- rep(NA, dim(parametersMCMC)[1])
-  names(rese) <- rownames(parametersMCMC)
-  out <- c(out, SE=list(rese))
-} else {
-  out <- c(out, BatchSE=list(coda::batchSE(out$resultMCMC, batchSize=batchSize)))
-}
-
-class(out) <- "mcmcComposite"
-
-fin <- try(summary(out), silent=TRUE)
-
-if (class(fin)=="try-error") {
-  lp <- rep(NA, nrow(out$parametersMCMC$parameters))
-  names(lp) <- rownames(out$parametersMCMC$parameters)
-  out <- c(out, TimeSeriesSE=list(lp))
-  out <- c(out, SD=list(lp))
-} else {
-  out <- c(out, TimeSeriesSE=list(fin$statistics[,4]))
-  out <- c(out, SD=list(fin$statistics[,"SD"]))
-}
-
-class(out) <- "mcmcComposite"
-
-return(out)
+                   intermediate=intermediate, filename=filename, previous=previous)
+  
+  if (batchSize>=n.iter/2) {
+    print("batchSize cannot be larger than half the number of iterations.")
+    rese <- rep(NA, dim(parametersMCMC)[1])
+    names(rese) <- rownames(parametersMCMC)
+    out <- c(out, SE=list(rese))
+  } else {
+    out <- c(out, BatchSE=list(coda::batchSE(out$resultMCMC, batchSize=batchSize)))
+  }
+  
+  out$resultML <- result
+  out$equation <- result$equation
+  
+  class(out) <- "mcmcComposite"
+  
+  fin <- try(summary(out), silent=TRUE)
+  
+  if (class(fin)=="try-error") {
+    lp <- rep(NA, nrow(out$parametersMCMC$parameters))
+    names(lp) <- rownames(out$parametersMCMC$parameters)
+    out <- c(out, TimeSeriesSE=list(lp))
+    out <- c(out, SD=list(lp))
+  } else {
+    out <- c(out, TimeSeriesSE=list(fin$statistics[,4]))
+    out <- c(out, SD=list(fin$statistics[,"SD"]))
+  }
+  
+  class(out) <- "mcmcComposite"
+  
+  return(out)
 }
